#!/bin/sh
set -e
set -u

# fetch first parameter
i=${1}
shift

# first parameter always must be the instance number [0-9]
case "${i}" in
    [0-9])
        # ok, break the case
        ;;
    *)
        echo "first parameter \"${i}\" must be the instancenumber: [0-9]" >&2
        exit 1
esac

# resolve symlinks to get the scriptDir
script=`readlink -e ${0}`
scriptDir=`dirname ${script}`

# clean the instance dir before parsing other parameters: fail clean if some parameters are wrong
absoluteInstanceDir=${scriptDir}/instance${i}
rm -rf ${absoluteInstanceDir}

# setup defaults
backup=false
backupGroupName="common"

# parse additional params
while [ ${#} -gt 0 ]; do
        param=${1}
        shift;
        case "${param}" in
                -backup-group-name)
                        backupGroupName=${1}
                        shift
                        ;;
                -backup)
                        backup=${1}
                        shift
                        ;;
                *)
                        # error
                        echo "unknown param \"${param}\"" >&2
                        exit 1
       esac
done

# create instance dir
mkdir ${absoluteInstanceDir}
targetConfigDir=${absoluteInstanceDir}/config

# setup ports for different instances
# don't change this here without changing HornetQTestDataProviderBeta.java
NETTY_PORT=625${i}0	
NETTY_BATCH_PORT=625${i}1
JNP_PORT=625${i}2
JNP_RMI_PORT=625${i}3
HOSTNAME=`hostname -i`

# clone the clustered config
cp -r ${scriptDir}/current/config/stand-alone/clustered ${targetConfigDir}

# but use our own template for easier substitution
cp ${scriptDir}/hornetq-configuration.xml ${targetConfigDir}
cp ${scriptDir}/hornetq-beans.xml ${targetConfigDir}

# now adjust our config
sed ${targetConfigDir}/hornetq-beans.xml -i \
	-e "s/JNP_PORT/${JNP_PORT}/" \
	-e "s/JNP_RMI_PORT/${JNP_RMI_PORT}/" \
	-e "s/HOSTNAME/${HOSTNAME}/"
sed ${targetConfigDir}/hornetq-configuration.xml -i \
	-e "s/NETTY_PORT/${NETTY_PORT}/" \
	-e "s/NETTY_BATCH_PORT/${NETTY_BATCH_PORT}/" \
	-e "s@INSTANCE_DIR@${absoluteInstanceDir}@" \
	-e "s/IS_BACKUP/${backup}/" \
	-e "s/BACKUP_GROUP_NAME/${backupGroupName}/" \
	-e "s/HOSTNAME/${HOSTNAME}/"
